fars_map_state: Map the accidents for a given US state and year

Description Usage Arguments Value Examples

Description

The function builds a map of the reported accidents in the selected state for the particuar year. A warning message is produced if entered state code is invalid, and if there is not any reported accidents for the given period of time.

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

The state index as an integer

year

The year of the accidents as an integer.

Value

The geographical map of the state with plotted traffic accidents. Each point represents a single case from the FARS data file for one specific year.

Examples

1
2
3
4
## Not run: 
fars_map_state(state.num = 10, year = 2013)

## End(Not run)

Kakakia/FarsFunctions documentation built on May 16, 2019, 4:03 a.m.