fars_read: Read .csv file into a data frame

Description Usage Arguments Value Examples

Description

The function loads US National Highway Traffic Safety Administration data and reads comma separated values file into a data frame. If file doesn't exist, a warning message will appear.

Usage

1
fars_read(filename)

Arguments

filename

The name of data file as a character string.

Value

The data file as a data frame.

Examples

1
2
3
4
## Not run: 
fars_read("accident_2013.csv.bz2")

## End(Not run)

Kakakia/FarsFunctions documentation built on May 16, 2019, 4:03 a.m.