fars_summarize_years: Calculate number of accidents per month for the particular...

Description Usage Arguments Value Examples

Description

The function summarises the accidents for the selected years and counts the number of reports per month.

Usage

1

Arguments

years

desired list of years for selecting data collected from the US National Highway Traffic Safety Administration's Fatality Analysis Reporting System, which is a nationwide census providing the American public yearly data regarding fatal injuries suffered in motor vehicle traffic crashes to be summarized.

Value

a summary table wich contains the number of accidents grouped by year and month of the given list of years

Examples

1
2
3
4
5
6
## Not run: 
fars_summarize_years(2013:2015)
fars_summarize_years(c(2013, 2014, 2015))
fars_summarize_years(list(2013, 2014, 2015))

## End(Not run)

Kakakia/FarsFunctions documentation built on May 16, 2019, 4:03 a.m.