make_filename: Create filename for a compressed bz2 file

Description Usage Arguments Value Examples

Description

The function creates a file name using a year as an input.This function makes reading files faster for the analysis of FARS data.

Usage

1

Arguments

year

The year of the accidents as an integer.

Value

The file name as a character string.

Examples

1
2
3
4
## Not run: 
make_filename(year = 2013)

## End(Not run)

Kakakia/FarsFunctions documentation built on May 16, 2019, 4:03 a.m.