Description Usage Arguments Value Examples
The function builds a map of the reported accidents in the selected state for the particuar year. A warning message is produced if entered state code is invalid, and if there is not any reported accidents for the given period of time.
1 | fars_map_state(state.num, year)
|
state.num |
The state index as an integer |
year |
The year of the accidents as an integer. |
The geographical map of the state with plotted traffic accidents. Each point represents a single case from the FARS data file for one specific year.
1 2 3 4 | ## Not run:
fars_map_state(state.num = 10, year = 2013)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.