Description Usage Arguments Value Examples
The function loads US National Highway Traffic Safety Administration data and reads comma separated values file into a data frame. If file doesn't exist, a warning message will appear.
1 | fars_read(filename)
|
filename |
The name of data file as a character string. |
The data file as a data frame.
1 2 3 4 | ## Not run:
fars_read("accident_2013.csv.bz2")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.