Description Usage Arguments Value Examples
The function creates a subset that contains accidents occured in the particular years and sorted by months. A warning message is produced if the specified year is not in the original dataset.
1 | fars_read_years(years)
|
years |
The years of the accidents as a list or vector of integers |
The accidents for given years sorted by month as list of data frames with integers and numeric elements. Returns NULL if entered year doesn't exist in the data set.
1 2 3 4 5 6 | ## Not run:
fars_read_years(years = 2013:2015)
fars_read_years(years = c(2013, 2014, 2015))
fars_read_years(years = list(2013,2014,2015))
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.