Description Usage Arguments Value Examples
The function summarises the accidents for the selected years and counts the number of reports per month.
1 | fars_summarize_years(years)
|
years |
desired list of years for selecting data collected from the US National Highway Traffic Safety Administration's Fatality Analysis Reporting System, which is a nationwide census providing the American public yearly data regarding fatal injuries suffered in motor vehicle traffic crashes to be summarized. |
a summary table wich contains the number of accidents grouped by year and month of the given list of years
1 2 3 4 5 6 | ## Not run:
fars_summarize_years(2013:2015)
fars_summarize_years(c(2013, 2014, 2015))
fars_summarize_years(list(2013, 2014, 2015))
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.