Description Usage Arguments Value Examples
The function creates a file name using a year as an input.This function makes reading files faster for the analysis of FARS data.
1 | make_filename(year)
|
year |
The year of the accidents as an integer. |
The file name as a character string.
1 2 3 4 | ## Not run:
make_filename(year = 2013)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.